#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "carte.h"
#include "structures.h"
#include <roxml.h>


/*!
* \file carte.c
* \brief Fichier contenant le code des fonctions liees aux cartes.
*/


char* ExtraireCarte(int numero)
{
    return LireCarte("../resources/Maps.txt",numero);
}


/*!
 * \fn Carte* LireCarte(int num)
 * \brief La fonction recupere la n-ieme carte dans un fichier et renvoie un pointeur sur la carte cree
 *
 * \return Un pointeur sur une tableau de cartes.
 */
char* LireCarte(const char *filename, int num)
{
    char char_actuel;
    int num_map = 0, nb_lignes = 0, nb_colonnes = 0, i=0, j=0, k=0, taille_Tableau = 0;
    FILE* file_map = NULL;
    file_map = fopen(filename, "r");

    fseek(file_map, 3, SEEK_SET);
    fscanf(file_map,"%d %d %d", &num_map, &nb_lignes, &nb_colonnes); /*! Lecture du nom et de la taille de la premiere map */

    fgetc(file_map);
    fgetc(file_map);

    while(num_map < num)    /*! Descend jusqu' la prochaine map */
    {
        for(k=0; k<nb_colonnes; k++) /*! Descend jusqu' la prochaine map */
        {
            fseek(file_map,nb_lignes+2,SEEK_CUR);
        }
        fgetc(file_map);
        fgetc(file_map);
        fseek(file_map, 3, SEEK_CUR);

        fscanf(file_map,"%d %d %d", &num_map, &nb_lignes, &nb_colonnes);  /*! Lecture du nom et de la taille de la map */
        fgetc(file_map);
        fgetc(file_map);
    }

    char * TableauCarte = NULL;
    taille_Tableau = nb_colonnes*nb_lignes*sizeof(char);
    TableauCarte = malloc(taille_Tableau);

    for(i=0; i<nb_colonnes; i++)
    {
        for(j=0; j<nb_lignes; j++)
        {
            char_actuel = fgetc(file_map);
            TableauCarte[nb_lignes*i+j] = char_actuel;
        }
        fgetc(file_map);
    }

    /* Test Tableau

        for(j=0; j<nb_lignes*nb_colonnes; j++)
        {
            printf("La valeur %d du tableau vaut : %c\n",j,TableauCarte[j]);
        }

        fclose(file_map);
    */
    return TableauCarte;
}


Carte_A* ExtraireCartesXML(const char *filename)
{
    node_t *rootXML, *Maps;
    int nb_Maps=0, i=0;
    rootXML = roxml_load_doc(filename);
    Maps = roxml_get_chld(rootXML, NULL, 0);

    nb_Maps = roxml_get_chld_nb(Maps);
    printf("Il y a %d maps\n", nb_Maps);

    Carte_A* Tableau_Cartes = malloc(nb_Maps * sizeof(Carte_A));

    /*-------------------------------------------------------------------------------------------------------------------*/
    /* Aquisition des cartes */
    /*-------------------------------------------------------------------------------------------------------------------*/

    for(i=0; i<nb_Maps; i++)
    {
        int j=0, nb_lignes=0, taille_lignes;
        char *id_text, *name_text, *desc_text, *lignes_text;
        node_t *Map_Actuelle;
        Map_Actuelle = roxml_get_chld(Maps,NULL,i);

        id_text = roxml_get_content(roxml_get_attr(Map_Actuelle, "id", 0), NULL, 0, NULL);
        name_text = roxml_get_content(roxml_get_attr(Map_Actuelle, "name", 0), NULL, 0, NULL);
        desc_text = roxml_get_content(roxml_get_attr(Map_Actuelle, "desc", 0), NULL, 0, NULL);
        taille_lignes = atoi(roxml_get_content(roxml_get_attr(Map_Actuelle, "taille_lignes", 0), NULL, 0, NULL));

        printf("Les lignes font %d de long\n", taille_lignes);


        nb_lignes = roxml_get_chld_nb(Map_Actuelle);

        Carte_A Carte_Actuelle;

        strcpy(Carte_Actuelle.id, id_text);
        strcpy(Carte_Actuelle.nom, name_text);
        strcpy(Carte_Actuelle.desc, desc_text);

        printf("L'ID est :%s\n\n", Carte_Actuelle.id);
        printf("Le nom est :%s\n\n", Carte_Actuelle.nom);
        printf("La desc est :%s\n\n", Carte_Actuelle.desc);

        /*--------------------------------------------------------------------------------------------------------------*/
        /* Aquisition des lignes de la carte */
        /*--------------------------------------------------------------------------------------------------------------*/

        for(j=0; j<nb_lignes; j++)
        {
            node_t* Ligne_Actuelle;
            Ligne_Actuelle = roxml_get_chld(Map_Actuelle, NULL, j);

            char* sequence_ligne;
            roxml_get_content(Ligne_Actuelle, sequence_ligne, 50, NULL);

            printf("Sequence_Ligne vaut : %s\n", sequence_ligne);

           // strcpy(Carte_Actuelle.lignes[j], sequence_ligne);

            //printf("La ligne %d vaut : %s\n",j+1, Carte_Actuelle.lignes[j]);
        }

        Tableau_Cartes[i] = Carte_Actuelle;


    }

    return Tableau_Cartes;
}


